@@ -76,7 +76,8 @@ def getStations(kraftstoff = diesel, place = '123', limit = '-1', asJson = False
                 "street": street,
                 "place": place,
                 "price": price,
-                "reloaded": reloaded
+                "reloaded": reloaded,
+                "pos": i +1,
             }
             if (limit == str(i)) and (limit != '-1'):
                 break
